@@ -17,6 +17,9 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 授权无效。
+AUTHFAILURE_INVALIDAUTHORIZATION = 'AuthFailure.InvalidAuthorization'
+
 # 子账号无权限。
 AUTHFAILURE_SUBACCOUNTDENIED = 'AuthFailure.SubAccountDenied'
 
@@ -83,6 +86,9 @@ FAILEDOPERATION_JSONUNMARSHALERROR = 'FailedOperation.JsonUnmarshalError'
 # 不是延迟复制RO。
 FAILEDOPERATION_NOTDELAYRO = 'FailedOperation.NotDelayRo'
 
+# 实例正在执行其他操作，请稍后重试。
+FAILEDOPERATION_OPERATIONINCONFLICTERR = 'FailedOperation.OperationInConflictErr'
+
 # 执行的权限修改操作非法。您可以参照产品文档，了解当前实例支持哪些权限修改操作，如有疑问，请您咨询客服进行处理。
 FAILEDOPERATION_PRIVILEGEDATAILLEGAL = 'FailedOperation.PrivilegeDataIllegal'
 
@@ -92,9 +98,6 @@ FAILEDOPERATION_PROXYGROUPSTATUSERROR = 'FailedOperation.ProxyGroupStatusError'
 # 查询日志失败。
 FAILEDOPERATION_QUERYLOGERROR = 'FailedOperation.QueryLogError'
 
-# 代理创建中或则已存在，请勿重复创建。
-FAILEDOPERATION_REPEATCREATEPROXYERROR = 'FailedOperation.RepeatCreateProxyError'
-
 # 后台请求服务异常，请您联系客服解决。
 FAILEDOPERATION_RESPONSEVALUEERROR = 'FailedOperation.ResponseValueError'
 
@@ -185,6 +188,9 @@ INTERNALERROR_FTPERROR = 'InternalError.FtpError'
 # Http请求异常。
 INTERNALERROR_HTTPERROR = 'InternalError.HttpError'
 
+# 导入失败。
+INTERNALERROR_IMPORTERROR = 'InternalError.ImportError'
+
 # 内部服务错误。
 INTERNALERROR_INNERCOMMONERROR = 'InternalError.InnerCommonError'
 
@@ -356,6 +362,9 @@ MISSINGPARAMETER_MISSINGPARAMERROR = 'MissingParameter.MissingParamError'
 # 操作被拒绝。
 OPERATIONDENIED = 'OperationDenied'
 
+# 云账号权限不足，不支持该操作。
+OPERATIONDENIED_ACCOUNTOPERATIONDENIED = 'OperationDenied.AccountOperationDenied'
+
 # 实例正在执行其他任务。
 OPERATIONDENIED_ACTIONINPROCESS = 'OperationDenied.ActionInProcess'
 
@@ -431,6 +440,9 @@ OPERATIONDENIED_INSTANCESTATUSERROR = 'OperationDenied.InstanceStatusError'
 # 当前实例正在进行其他任务，不能执行延迟复制。
 OPERATIONDENIED_INSTANCETASKRUNNING = 'OperationDenied.InstanceTaskRunning'
 
+# 实例任务状态异常。
+OPERATIONDENIED_INSTANCETASKSTATUSERROR = 'OperationDenied.InstanceTaskStatusError'
+
 # 实例不支持该操作。
 OPERATIONDENIED_INSTANCEUNSUPPORTEDOPERATEERROR = 'OperationDenied.InstanceUnsupportedOperateError'
 
